--[[
	CS_DetailFrame.lua - Is a support module file for the CombatStats
	World of Warcraft addon.  This modules functionality is to support all the 
	display of detailed attack information window/frame.
	
	Copyright (C) 2011 Brian Beardmore - wowaddon(at)realisticsoftware(dot)com

	Revisions:
		2010.11.04 BAB	fixes for WoW 4.0.1
		2010.01.22 BAB	fixed 3.3 drop down menu problem
		2009.04.16 BAB	cleanup old 3.0 and 2.4 special switch code
		2008.08.21 BAB	added CombatStats_Fr_GeneralMissedDmg info to the window
						moved the CombatStats_Fr_GeneralMissesTextLabel up under the attack name
						no longer use gCS.totalDamage in this file
		2007.11.23 BAB	Fixed a nil record usage bug in CombatStats_UpdateDetails
		2007.08.26 BAB	The file was created from functions extracted from the
						prior CombatStats.lua file.  The code was written by DmgInc,
						other authors and Brian Beardmore.
						
	License:
		This program is free software; you can redistribute it and/or
		modify it under the terms of the GNU General Public License
		as published by the Free Software Foundation; either version 2
		of the License, or (at your option) any later version.

		This program is distributed in the hope that it will be useful,
		but WITHOUT ANY WARRANTY; without even the implied warranty of
		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
		GNU General Public License for more details.

		You should have received a copy of the GNU General Public License
		along with this program(see GPL.txt); if not, write to the Free Software
		Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
]]


-- Debug switch - set to true, to enable debug output for this module
local debug = false;

-------------------------------------------------------------------------------
-- Uses and requires
-------------------------------------------------------------------------------
	-- CombatStats.Utils..  & CombatStats.AttackHistDB..

-------------------------------------------------------------------------------
-- Function Imports
-------------------------------------------------------------------------------
local sortAttackNames = CombatStats.AttackHistDB.SortAttackNames;
local setGrpSortType = CombatStats.AttackHistDB.SetGrpSortType;
local getMissAttackData = CombatStats.AttackHistDB.GetMissOverallAttackData;
local debugPrint = CombatStats.Utils.DebugPrint;

-------------------------------------------------------------------------------
-- Function Prototypes
-------------------------------------------------------------------------------
local load;

local bracketPercentText;
local bracketPercentTextFactionIn;
local isAttackHealing;

local removeAttackEntry;
local removeAttackGroup;
local removeAttackGroupCallback;
local removeAttacksOlderThan;
local removeAttacksOlderThanCallback;

local setDirtyAttackMenu;
local fillAttackNamesMenu;
local fillAttackNamesSubmenu;
local editDropDownMenuInitialize;
local groupsMenuToggleLabel;
local autoResetBattleMenuToggleLabel;

local fillAttackNmRegCallback;
local fillAttackNmGrpCallback;
local fillAttackNmCallback;
local fillSubAttackMenuCallback;

local resetGroupList;
local clearGroupList;
local setActiveNameGroupList;
local isActiveNameGroupList;

local sortAttackMenuComp;
-------------------------------------------------------------------------------
-- Data Members
-------------------------------------------------------------------------------
local _L = {
	kHealNmAType = CS_ATTACK_HEAL_PRE_LABEL,
	firstShow = 1,
	dirtyAttackMenu = 1,
	groupList = {},
	
		-- for GUI default and empty values
	kTotalType = format(CS_K_NUMBER_FORMAT_1P, 0),
	kPercentTxt = format(CS_K_PERCENT_FORMAT_1P, 0),
	kPercentTxt2 = format(CS_K_PERCENT_FORMAT_2P, 0),
	kBracketPercentTxt = format(CS_K_BRACKET_PERCENT_FORMAT, 0),
};

-------------------------------------------------------------------------------
-- Constants
-------------------------------------------------------------------------------


-------------------------------------------------------------------------------
-- Loads this module.
-------------------------------------------------------------------------------
function load()
end

--=============================================================================
-- ?? functions
--=============================================================================

function CombatStatsAttack_OnClick(self)
	local attackName = self.value;
	
	if(attackName ~= nil) then
		CombatStatsAttackDropDown_SetText(attackName);
		--UIDropDownMenu_SetSelectedValue(CombatStatsAttackDropDownTest, attackName);
		CombatStats_UpdateDetails(attackName);
	end
end

function CombatStatsAttackSubMenu_OnClick(self)
	local attackName = nil;
	
	if(CombatStats.AttackHistDB.GetAttackNameCount() >= self.value) then
		attackName = CombatStats.AttackHistDB.GetAttackName(self.value);
		self.attackName = attackName;
	end
	if(attackName ~= nil) then
		CombatStatsAttackDropDown_SetText(attackName);
		--UIDropDownMenu_SetSelectedValue(CombatStatsAttackDropDownTest, attackName, 1);
		CombatStats_UpdateDetails(attackName);
	end
	--ToggleDropDownMenu(1, nil, CombatStatsAttackDropDownTest, nil, 1, 1);
	CloseDropDownMenus();
end

function CombatStatsAttackDropDown_GetText()
	return UIDropDownMenu_GetText(CombatStatsAttackDropDownTest);
end

function CombatStatsAttackDropDown_SetText(theText)
	UIDropDownMenu_SetSelectedValue(CombatStatsAttackDropDownTest, theText);
	UIDropDownMenu_SetText(CombatStatsAttackDropDownTest, theText);
	--UIDropDownMenu_SetSelectedValue(CombatStatsAttackDropDownTest, theText);
end

--[[
function CombatStatsAttackDropDown_OnLoad(self)
	--debugPrint("CombatStatsAttackDropDown_OnLoad");
	
	UIDropDownMenu_Initialize(self, CombatStatsAttackDropDown_Initialize, "MENU", 1);
	
	UIDropDownMenu_SetWidth(self, 154);		-- now in XML file;
	--UIDropDownMenu_SetSelectedID(self, 1);
	UIDropDownMenu_JustifyText(self, "LEFT");
end
]]

function CombatStatsAttackDropDown_Setup(self)
	--debugPrint("CombatStatsAttackDropDown_Setup");
	UIDropDownMenu_SetWidth(self, 154);
	UIDropDownMenu_JustifyText(self, "LEFT");
	UIDropDownMenu_Initialize(self, CombatStatsAttackDropDown_Initialize);
	if (gCS.currentAttack) then CombatStatsAttackDropDown_SetText(gCS.currentAttack); end;
end

function CombatStatsText_ResetFrameGUI()
	CombatStats_Fr_GeneralNameTextLabel:SetText(CS_TEXT_NA);
	CombatStats_Fr_NonCritHitsStatText:SetText("0");
	CombatStats_Fr_NonCritDamageStatText:SetText("0");
	CombatStats_Fr_NonCritMinMaxStatText:SetText("0/0");
	CombatStats_Fr_NonCritAvgStatText:SetText(_L.kTotalType);
	CombatStats_Fr_NonCritPercentDamageStatText:SetText(_L.kPercentTxt);
	CombatStats_Fr_CritHitsStatText:SetText("0");
	CombatStats_Fr_CritDamageStatText:SetText("0");
	CombatStats_Fr_CritMinMaxStatText:SetText("0/0");
	CombatStats_Fr_CritAvgStatText:SetText(_L.kTotalType);
	CombatStats_Fr_CritPercentDamageStatText:SetText(_L.kPercentTxt);
	CombatStats_Fr_GeneralPercentDmgPctLabel:SetText(_L.kPercentTxt2);
	CombatStats_Fr_GeneralHitsSwingLineLabel:SetText(format(CS_K_SWING_FORMAT,0,0));
	--CombatStats_Fr_GeneralSwingsLabel:SetText("0");
	CombatStats_Fr_GeneralMissesTextLabel:SetText("0");
	CombatStats_Fr_GeneralMissesPercentLabel:SetText(_L.kBracketPercentTxt);
	CombatStats_Fr_GeneralDodgesTextLabel:SetText("0");
	CombatStats_Fr_GeneralDodgesPercentLabel:SetText(_L.kBracketPercentTxt);
	CombatStats_Fr_GeneralParriedTextLabel:SetText("0");
	CombatStats_Fr_GeneralParriedPercentLabel:SetText(_L.kBracketPercentTxt);
	CombatStats_Fr_GeneralBlockedTextLabel:SetText("0");
	CombatStats_Fr_GeneralBlockedPercentLabel:SetText(_L.kBracketPercentTxt);
	CombatStats_Fr_GeneralResistedTextLabel:SetText("0");
	CombatStats_Fr_GeneralResistedPercentLabel:SetText(_L.kBracketPercentTxt);
	CombatStats_Fr_GeneralImmunedTextLabel:SetText("0");
	CombatStats_Fr_GeneralImmunedPercentLabel:SetText(_L.kBracketPercentTxt);
	CombatStats_Fr_GeneralEvadedTextLabel:SetText("0");
	CombatStats_Fr_GeneralEvadedPercentLabel:SetText(_L.kBracketPercentTxt);
	CombatStats_Fr_GeneralDeflectedTextLabel:SetText("0");
	CombatStats_Fr_GeneralDeflectedPercentLabel:SetText(_L.kBracketPercentTxt);
	--CombatStats_Fr_GeneralMissedDmgTextLabel:SetText("0");
	--CombatStats_Fr_GeneralMissedDmgPercentLabel:SetText(_L.kBracketPercentTxt);
	CombatStats_Fr_GeneralMissedDmgData:SetText("0");
	
	CombatStats_Fr_GeneralTimeLastCritTimeLabel:SetText(GREEN_FONT_COLOR_CODE..CS_TEXT_NA);
	CombatStats_Fr_OverallCritPctStatText:SetText(RED_FONT_COLOR_CODE.._L.kPercentTxt);
	CombatStats_Fr_AttackNonCritPctStatText:SetText(GREEN_FONT_COLOR_CODE.._L.kPercentTxt);
	CombatStats_Fr_AttackCritPctStatText:SetText(RED_FONT_COLOR_CODE.._L.kPercentTxt);
	CombatStatsAttackDropDown_SetText(CS_DROPDOWN_SELECT_TEXT);
end

function CombatStatsText_ShowFrame()

	if(_L.firstShow == 1) then
		--
		--	Set all the default values
		--
		CombatStats_Fr_OverallCritPctLabel:SetText(CS_FRAME_GEN_ATTACK_TITLE);
		CombatStats_Fr_GeneralNameLabel:SetText(CS_FRAME_GEN_ATTACK_NAME);
		CombatStats_Fr_GeneralPercentDmgLabel:SetText(CS_FRAME_PERCENT_OVERALL_TEXT);
		CombatStats_Fr_GeneralMissesLabel:SetText(CS_FRAME_MISSES_TEXT);
		CombatStats_Fr_GeneralDodgesLabel:SetText(CS_FRAME_DODGES_TEXT);
		CombatStats_Fr_GeneralParriedLabel:SetText(CS_FRAME_PARRIES_TEXT);
		CombatStats_Fr_GeneralBlockedLabel:SetText(CS_FRAME_BLOCKS_TEXT);
		CombatStats_Fr_GeneralResistedLabel:SetText(CS_FRAME_RESISTS_TEXT);
		CombatStats_Fr_GeneralImmunedLabel:SetText(CS_FRAME_IMMUNE_TEXT);
		CombatStats_Fr_GeneralEvadedLabel:SetText(CS_FRAME_EVADES_TEXT );
		CombatStats_Fr_GeneralDeflectedLabel:SetText(CS_FRAME_DEFLECTS_TEXT);
		CombatStats_Fr_GeneralMissedDmgLabel:SetText(CS_FRAME_MISSDMG_TEXT);
		CombatStats_Fr_GeneralTimeLastCritLabel:SetText(CS_FRAME_TIME_LASTCRIT_TEXT);
		CombatStats_Fr_AttackNonCritPctLabel:SetText(CS_FRAME_NONCRIT_TEXT);
		CombatStats_Fr_NonCritHitsLabel:SetText(CS_FRAME_TOTAL_TEXT);
		CombatStats_Fr_NonCritDamageLabel:SetText(CS_FRAME_DAMAGE_TEXT);
		CombatStats_Fr_NonCritMinMaxLabel:SetText(CS_FRAME_MINMAX_TEXT);
		CombatStats_Fr_NonCritAvgLabel:SetText(CS_FRAME_AVGDMG_TEXT);
		CombatStats_Fr_NonCritPercentDamageLabel:SetText(CS_FRAME_PERCENTDMG_TEXT);
		CombatStats_Fr_AttackCritPctLabel:SetText(CS_FRAME_CRIT_TEXT);
		CombatStats_Fr_CritHitsLabel:SetText(CS_FRAME_TOTAL_TEXT);
		CombatStats_Fr_CritDamageLabel:SetText(CS_FRAME_DAMAGE_TEXT);
		CombatStats_Fr_CritMinMaxLabel:SetText(CS_FRAME_MINMAX_TEXT);
		CombatStats_Fr_CritAvgLabel:SetText(CS_FRAME_AVGDMG_TEXT);
		CombatStats_Fr_CritPercentDamageLabel:SetText(CS_FRAME_PERCENTDMG_TEXT);
		
		if(gCS.currentAttack ~= nil and gCS.currentAttack ~= CS_TEXT_NA)
		then
			CombatStats_UpdateDetails(gCS.currentAttack);
			CombatStatsAttackDropDown_SetText(gCS.currentAttack);
		else
			CombatStatsText_ResetFrameGUI();
		end
		
		setDirtyAttackMenu();
		_L.firstShow = 0;
	end
	
	if( CombatStatsAttackDropDown_GetText() ~= CS_DROPDOWN_SELECT_TEXT) then
		CombatStats_UpdateDetails( CombatStatsAttackDropDown_GetText() );
	end
	CombatStatsDataFrame:Show();
end

function bracketPercentText(theValue, theTotal)
	if(theTotal == 0) then return _L.kBracketPercentTxt; end
	
	return (bracketPercentTextFactionIn(theValue / theTotal));
	
	--[[
	local aStr = nil;
	
	if(theTotal ~= 0) then
		if(theTotal ~= theValue) then
			aStr = format(CS_K_BRACKET_PERCENT_FORMAT, (theValue / theTotal * 100));
		else
			-- done to only show 1 '0' after decimal
			aStr = format(NORMAL_FONT_COLOR_CODE.."["..WHITE_FONT_COLOR_CODE.."%.0f%%"..NORMAL_FONT_COLOR_CODE.."]", 100);
		end
	else
		aStr = _L.kBracketPercentTxt;
	end
	
	return aStr;
	]]
end

function bracketPercentTextFactionIn(theFaction)
	local aStr = nil;
	
	if(theFaction < 1) then
		aStr = format(CS_K_BRACKET_PERCENT_FORMAT, (theFaction * 100));
	else
		-- done to only show 1 '0' after decimal
		aStr = format(NORMAL_FONT_COLOR_CODE.."["..WHITE_FONT_COLOR_CODE.."%.0f%%"..NORMAL_FONT_COLOR_CODE.."]", (theFaction * 100));
	end
	
	return aStr;
end

function isAttackHealing(attackName)
	if (attackName == nil) then return false; end
	
	--return ( strsub(attackName, 0, 6) == kHealNmAType );
	return ( strsub(attackName, 0, string.len(_L.kHealNmAType)) == _L.kHealNmAType );
	-- Cleanup or fix when possible -- should likely add heal flag to attack record
end
	
function CombatStats_UpdateDetails(attackName, ifSelected)

	local	deltaTime = 0;
	local	totAttack;
	local	recAttack;
	local	tmpCount, tmpDmg, tmpDmgPercent;
	ifSelected = ifSelected or false;
	
	-- sanity check
	if (attackName == nil) then CombatStatsText_ResetFrameGUI() return; end;
	
	--
	--	Retrieve the attack records of interest
	recAttack = CombatStats.AttackHistDB.GetAttackRec(attackName, false);
	totAttack = CombatStats.AttackHistDB.GetAttackRec(CS_ATTACK_TOTAL_LABEL, false);
	if ((recAttack == nil) or (totAttack == nil)) then
		CombatStatsText_ResetFrameGUI();
		return;
	end
	
	if ((ifSelected) and (gCS.currentAttack ~= attackName)) then return; end;
	
	_, tmpDmg, tmpDmgPercent = getMissAttackData(attackName, CombatStats.kTotalType);
	
	--
	--	Setup and switch display labels if healing attack is being displayed
	gCS.currentAttack = attackName;
	if ( isAttackHealing(attackName) ) then
		CS_TT_NONCRIT_HITSPCT_TEXT = CS_TT_NONCRIT_HITSPCT_TEXT_HEAL;
		CS_TT_CRIT_HITSPCT_TEXT = CS_TT_CRIT_HITSPCT_TEXT_HEAL;
		CS_TT_OVERALLDMGPCT_TEXT = CS_TT_OVERALLDMGPCT_TEXT_HEAL;
		CS_TT_CRIT_DMGPCT_TEXT = CS_TT_CRIT_DMGPCT_TEXT_HEAL;
		CS_TT_NONCRIT_DMGPCT_TEXT = CS_TT_NONCRIT_DMGPCT_TEXT_HEAL;
		CombatStats_Fr_GeneralPercentDmgLabel:SetText(CS_FRAME_PERCENT_OVERALL_TEXT_HEAL);
		CombatStats_Fr_NonCritDamageLabel:SetText(CS_FRAME_DAMAGE_TEXT_HEAL);
		CombatStats_Fr_NonCritAvgLabel:SetText(CS_FRAME_AVGDMG_TEXT_HEAL);
		CombatStats_Fr_NonCritPercentDamageLabel:SetText(CS_FRAME_PERCENTDMG_TEXT_HEAL);
		CombatStats_Fr_CritDamageLabel:SetText(CS_FRAME_DAMAGE_TEXT_HEAL);
		CombatStats_Fr_CritAvgLabel:SetText(CS_FRAME_AVGDMG_TEXT_HEAL);
		CombatStats_Fr_CritPercentDamageLabel:SetText(CS_FRAME_PERCENTDMG_TEXT_HEAL);
		CombatStats_Fr_GeneralMissedDmgLabel:SetText(CS_FRAME_MISSDMG_TEXT_HEAL);
		CombatStats_Fr_GeneralMissedDmgData:SetText(format(CS_FRAME_PERHITDMG_TEXT_HEAL,tmpDmg,bracketPercentTextFactionIn(tmpDmgPercent)));
	else
		CS_TT_NONCRIT_HITSPCT_TEXT = CS_TT_NONCRIT_HITSPCT_TEXT_NONHEAL;
		CS_TT_CRIT_HITSPCT_TEXT = CS_TT_CRIT_HITSPCT_TEXT_NONHEAL;
		CS_TT_OVERALLDMGPCT_TEXT = CS_TT_OVERALLDMGPCT_TEXT_NONHEAL;
		CS_TT_CRIT_DMGPCT_TEXT = CS_TT_CRIT_DMGPCT_TEXT_NONHEAL;
		CS_TT_NONCRIT_DMGPCT_TEXT = CS_TT_NONCRIT_DMGPCT_TEXT_NONHEAL;
		CombatStats_Fr_GeneralPercentDmgLabel:SetText(CS_FRAME_PERCENT_OVERALL_TEXT);
		CombatStats_Fr_NonCritDamageLabel:SetText(CS_FRAME_DAMAGE_TEXT);
		CombatStats_Fr_NonCritAvgLabel:SetText(CS_FRAME_AVGDMG_TEXT);
		CombatStats_Fr_NonCritPercentDamageLabel:SetText(CS_FRAME_PERCENTDMG_TEXT);
		CombatStats_Fr_CritDamageLabel:SetText(CS_FRAME_DAMAGE_TEXT);
		CombatStats_Fr_CritAvgLabel:SetText(CS_FRAME_AVGDMG_TEXT);
		CombatStats_Fr_CritPercentDamageLabel:SetText(CS_FRAME_PERCENTDMG_TEXT);
		CombatStats_Fr_GeneralMissedDmgLabel:SetText(CS_FRAME_MISSDMG_TEXT);
		CombatStats_Fr_GeneralMissedDmgData:SetText(format(CS_FRAME_PERHITDMG_TEXT,tmpDmg,bracketPercentTextFactionIn(tmpDmgPercent)));
	end
	
	--
	-- Calculate % of hits that are crits
	--
	
	if( totAttack.totalHits ~= 0) then
		CombatStats_Fr_OverallCritPctStatText:SetText( format(RED_FONT_COLOR_CODE.."%.2f %%", ( totAttack.totalCrits / totAttack.totalHits) * 100.0));
	end
	
	CombatStats_Fr_GeneralNameTextLabel:SetText(attackName);

	if ( isAttackHealing(attackName) ) then
		CombatStats_Fr_GeneralHitsSwingLineLabel:SetText(format(CS_K_SWING_FORMAT_HEAL,recAttack.totalHits));
	else
		CombatStats_Fr_GeneralHitsSwingLineLabel:SetText(format(CS_K_SWING_FORMAT,recAttack.totalHits,recAttack.totalSwings));
	end

	
	tmpCount = getMissAttackData(attackName, CombatStats.kMissType);

	CombatStats_Fr_GeneralMissesTextLabel:SetText(tmpCount);
	CombatStats_Fr_GeneralMissesPercentLabel:SetText(bracketPercentText(tmpCount, recAttack.totalSwings));
	
	tmpCount = getMissAttackData(attackName, CombatStats.kDodgeType);
	CombatStats_Fr_GeneralDodgesTextLabel:SetText(tmpCount);
	CombatStats_Fr_GeneralDodgesPercentLabel:SetText(bracketPercentText(tmpCount, recAttack.totalSwings));
	
	tmpCount = getMissAttackData(attackName, CombatStats.kBlockType);
	CombatStats_Fr_GeneralBlockedTextLabel:SetText(tmpCount);
	if(attackName == CS_ATTACK_DEFENSE_LABEL) then
		CombatStats_Fr_GeneralBlockedPercentLabel:SetText(bracketPercentText(tmpCount, recAttack.totalHits));
	else
		CombatStats_Fr_GeneralBlockedPercentLabel:SetText(bracketPercentText(tmpCount, recAttack.totalSwings));
	end
	
	tmpCount = getMissAttackData(attackName, CombatStats.kParryType);
	CombatStats_Fr_GeneralParriedTextLabel:SetText(tmpCount);
	CombatStats_Fr_GeneralParriedPercentLabel:SetText(bracketPercentText(tmpCount, recAttack.totalSwings));
	
	tmpCount = getMissAttackData(attackName, CombatStats.kResistType);
	CombatStats_Fr_GeneralResistedTextLabel:SetText(tmpCount);
	CombatStats_Fr_GeneralResistedPercentLabel:SetText(bracketPercentText(tmpCount, recAttack.totalSwings));
	
	tmpCount = getMissAttackData(attackName, CombatStats.kImmuneType);
	CombatStats_Fr_GeneralImmunedTextLabel:SetText(tmpCount);
	CombatStats_Fr_GeneralImmunedPercentLabel:SetText(bracketPercentText(tmpCount, recAttack.totalSwings));
	
	tmpCount = getMissAttackData(attackName, CombatStats.kEvadeType);
	CombatStats_Fr_GeneralEvadedTextLabel:SetText(tmpCount);
	CombatStats_Fr_GeneralEvadedPercentLabel:SetText(bracketPercentText(tmpCount, recAttack.totalSwings));
	
	tmpCount = getMissAttackData(attackName, CombatStats.kDeflectType);
	CombatStats_Fr_GeneralDeflectedTextLabel:SetText(tmpCount);
	CombatStats_Fr_GeneralDeflectedPercentLabel:SetText(bracketPercentText(tmpCount, recAttack.totalSwings));

	--
	--	Percent of total damage
	--
	if(attackName ~= CS_ATTACK_DEFENSE_LABEL) then
		if ( attackName == CS_ATTACK_HEAL_TOT_LABEL ) then
			CombatStats_Fr_GeneralPercentDmgPctLabel:SetText(format(CS_K_PERCENT_FORMAT_2P,100));
		elseif ( isAttackHealing(attackName) ) then
			--[[
			FIX
			if ( recAttack.totalHits ~= 0 ) then
				CombatStats_Fr_GeneralPercentDmgPctLabel:SetText(format(CS_K_PERCENT_FORMAT_2P, ((recAttack.totalRegDmg + recAttack.totalCritDmg + recAttack.dotDmg) / (specialAttacks[CS_ATTACK_HEAL_TOT_LABEL].totalRegDmg + specialAttacks[CS_ATTACK_HEAL_TOT_LABEL].totalCritDmg + specialAttacks[CS_ATTACK_HEAL_TOT_LABEL].dotDmg)) * 100) );
			else
				CombatStats_Fr_GeneralPercentDmgPctLabel:SetText(_L.kPercentTxt2);
			end
			]]
			CombatStats_Fr_GeneralPercentDmgPctLabel:SetText(_L.kPercentTxt2);
		else
			if(recAttack.totalHits ~=0) then
				--CombatStats_Fr_GeneralPercentDmgPctLabel:SetText(format(CS_K_PERCENT_FORMAT_2P, ((recAttack.totalRegDmg + recAttack.totalCritDmg + recAttack.dotDmg) / gCS.totalDamage) * 100) );
				CombatStats_Fr_GeneralPercentDmgPctLabel:SetText(format(CS_K_PERCENT_FORMAT_2P, 
					((recAttack.totalRegDmg + recAttack.totalCritDmg + recAttack.dotDmg) / 
						(totAttack.totalRegDmg + totAttack.totalCritDmg + totAttack.dotDmg)) * 100) );
			else
				CombatStats_Fr_GeneralPercentDmgPctLabel:SetText(_L.kPercentTxt2);
			end
		end
	end
	
	--
	--	Time since last crit
	--
	if(recAttack.lastCrit ~= 0) then
		deltaTime = time() - recAttack.lastCrit;
		if (deltaTime < (2*31526000))
		then CombatStats_Fr_GeneralTimeLastCritTimeLabel:SetText(
				GREEN_FONT_COLOR_CODE ..CombatStats.Utils.ClockFormatDeltaTime(deltaTime));
		-- fixed this time calculation to correctly use the sys date time and not uptime		--	BAB 2007.04.05;
		else CombatStats_Fr_GeneralTimeLastCritTimeLabel:SetText(GREEN_FONT_COLOR_CODE .."long ago (pre 4.0 vers)");
		end
	else
		CombatStats_Fr_GeneralTimeLastCritTimeLabel:SetText(GREEN_FONT_COLOR_CODE..CS_TEXT_NA);
	end
	
	--
	--	Attack Crit %
	--
	if (recAttack.totalHits ~= 0) and (recAttack.totalCrits ~= 0) then
		CombatStats_Fr_AttackCritPctStatText:SetText(format(RED_FONT_COLOR_CODE..CS_K_PERCENT_FORMAT_1P, ( (recAttack.totalCrits) / (recAttack.totalHits)) * 100.0 ));
	else
		CombatStats_Fr_AttackCritPctStatText:SetText(RED_FONT_COLOR_CODE.._L.kPercentTxt);
	end
	
	--
	--	Attack Non Crit %
	--
	if (recAttack.totalHits ~= 0) and (recAttack.totalNonCrits ~= 0) then
		CombatStats_Fr_AttackNonCritPctStatText:SetText( format(GREEN_FONT_COLOR_CODE..CS_K_PERCENT_FORMAT_1P, ( (recAttack.totalNonCrits) / (recAttack.totalHits)) * 100.0 ));
	else
		CombatStats_Fr_AttackNonCritPctStatText:SetText(GREEN_FONT_COLOR_CODE.._L.kPercentTxt);
	end
	
	--
	--	Non Crit stats
	--
	CombatStats_Fr_NonCritHitsStatText:SetText(recAttack.totalNonCrits);
	CombatStats_Fr_NonCritDamageStatText:SetText(recAttack.totalRegDmg);
	CombatStats_Fr_NonCritMinMaxStatText:SetText(recAttack.minReg .."/"..recAttack.maxReg);
	if( recAttack.totalRegDmg ~= 0) then
		if( (recAttack.totalHits - recAttack.totalCrits) < 0) then
			CombatStats_Fr_NonCritAvgStatText:SetText(format(CS_K_NUMBER_FORMAT_1P,	recAttack.totalRegDmg / (recAttack.totalCrits - recAttack.totalHits ) ));
		elseif( (recAttack.totalHits - recAttack.totalCrits) == 0 ) then
			CombatStats_Fr_NonCritAvgStatText:SetText(format(CS_K_NUMBER_FORMAT_1P, recAttack.totalRegDmg / (recAttack.totalCrits) ));
		elseif( (recAttack.totalHits - recAttack.totalCrits) > 0 ) then
			CombatStats_Fr_NonCritAvgStatText:SetText(format(CS_K_NUMBER_FORMAT_1P,recAttack.totalRegDmg / (recAttack.totalHits - recAttack.totalCrits) ));
		end
	else
		CombatStats_Fr_NonCritAvgStatText:SetText(_L.kTotalType);
	end
	if(recAttack.totalNonCrits ~=0) then
		CombatStats_Fr_NonCritPercentDamageStatText:SetText(format(CS_K_PERCENT_FORMAT_2P, ( recAttack.totalRegDmg	  / (recAttack.totalRegDmg + recAttack.totalCritDmg )) * 100.0));
	else
		CombatStats_Fr_NonCritPercentDamageStatText:SetText(_L.kPercentTxt2);
	end
	
	--
	--	Crit stats
	--
	CombatStats_Fr_CritHitsStatText:SetText(recAttack.totalCrits);
	CombatStats_Fr_CritDamageStatText:SetText(recAttack.totalCritDmg);
	CombatStats_Fr_CritMinMaxStatText:SetText(recAttack.minCrit .."/"..recAttack.maxCrit);
	if( recAttack.totalCritDmg ~= 0) then
		CombatStats_Fr_CritAvgStatText:SetText(format(CS_K_NUMBER_FORMAT_1P, (recAttack.totalCritDmg / recAttack.totalCrits) ));
	else
		CombatStats_Fr_CritAvgStatText:SetText(_L.kTotalType);
	end
	if(recAttack.totalCrits ~=0) then
		CombatStats_Fr_CritPercentDamageStatText:SetText(format(CS_K_PERCENT_FORMAT_2P, (recAttack.totalCritDmg / ( recAttack.totalRegDmg + recAttack.totalCritDmg )) * 100.0 ));
	else
		CombatStats_Fr_CritPercentDamageStatText:SetText(_L.kPercentTxt2);
	end
	
	--
	--	Show DOT Stats
	--
	if (recAttack.isDOT ==1) then
		CombatStats_Fr_GeneralHitsSwingLineLabel:SetText(format(CS_K_SWING_FORMAT_DOT,recAttack.dotTicks));
		CombatStats_Fr_NonCritHitsStatText:SetText(recAttack.dotTicks);
		CombatStats_Fr_NonCritDamageStatText:SetText(recAttack.dotDmg);
		CombatStats_Fr_NonCritMinMaxStatText:SetText(recAttack.minReg .."/"..recAttack.maxReg);
		CombatStats_Fr_NonCritAvgStatText:SetText(format(CS_K_NUMBER_FORMAT_1P,  recAttack.dotDmg /  recAttack.dotTicks	));
		CombatStats_Fr_NonCritPercentDamageStatText:SetText("100.0 %");
		CombatStats_Fr_AttackNonCritPctStatText:SetText(GREEN_FONT_COLOR_CODE.."100.0%");
		
		--
		--	Should never be a 0 tick entry but just in case
		--
			--		if(specialAttacks[attackNames[y]].dotTicks ~= 0) then
			--			text = text.."\n"..format(TEXT(DOT_AVERAGE),(specialAttacks[attackNames[y]].dotDmg / specialAttacks[attackNames[y]].dotTicks));
			--		end
	elseif ( recAttack.isDOT ==2) then
		CombatStats_Fr_GeneralHitsSwingLineLabel:SetText(format(CS_K_SWING_FORMAT_HOT,recAttack.dotTicks));
		CombatStats_Fr_NonCritHitsStatText:SetText(recAttack.dotTicks);
		CombatStats_Fr_NonCritDamageStatText:SetText(recAttack.dotDmg);
		CombatStats_Fr_NonCritMinMaxStatText:SetText(recAttack.minReg .."/"..recAttack.maxReg);
		CombatStats_Fr_NonCritAvgStatText:SetText(format(CS_K_NUMBER_FORMAT_1P,  recAttack.dotDmg /  recAttack.dotTicks	));
		CombatStats_Fr_NonCritPercentDamageStatText:SetText("100.0 %");
		CombatStats_Fr_AttackNonCritPctStatText:SetText(GREEN_FONT_COLOR_CODE.."100.0%");
	end

end

--
-- Attack data entry modifying functions
--

function sortAttackMenuComp(a,b)
	--debugPrint("a: "..a.." - b: "..b);
	local aRec = CombatStats.AttackHistDB.GetAttackRec(a, false);
	local bRec = CombatStats.AttackHistDB.GetAttackRec(b, false);
	if ((aRec == nil) or (bRec == nil)) then return false; end
	--debugPrint("CombatStats_Config.CombatStats_AttackMenuSort = "..CombatStats_Config.CombatStats_AttackMenuSort);
	
	if(CombatStats_Config.CombatStats_AttackMenuSort == 3) then
		-- sort order, largest max non-crit;
		if (aRec.maxReg == bRec.maxReg) then
			return a<b;
		end
		return aRec.maxReg>bRec.maxReg;
	elseif(CombatStats_Config.CombatStats_AttackMenuSort == 2) then
		-- sort order, largest max crit;
		if (aRec.maxCrit == bRec.maxCrit) then
			return a<b;
		end
		return aRec.maxCrit>bRec.maxCrit;
	elseif(CombatStats_Config.CombatStats_AttackMenuSort == 1) then
		-- sort order, newest last crit;
		if (aRec.lastCrit == bRec.lastCrit) then
			return a<b;
		end
		return aRec.lastCrit>bRec.lastCrit;
	else
		-- sort order, attack name;
		return a<b;
	end
end

function removeAttackEntry(attackName)
	if (attackName == nil) then return; end

	CombatStats.AttackHistDB.ClearRecFromAttacksDB(attackName);
	clearGroupList(true);		--- needs more work
	
	if(attackName == gCS.currentAttack) then
		gCS.currentAttack = CS_TEXT_NA;
		CombatStatsText_ResetFrameGUI();
	end
end

function removeAttackGroupCallback(attackName, groupName)
	local grpNm = CombatStats.AttackHistDB.GetGroupNameForAttackName(attackName,CombatStats_Config.CombatStats_AttackMenu1stGrping);
	if ((grpNm ~= nil) and (attackName ~= nil)) then
		debugPrint("  grpNm: "..grpNm..", for attackName: "..attackName);
	end
	
	if ((grpNm ~= nil) and (grpNm == groupName)) then
		debugPrint("Attack: "..attackName..", in group: "..groupName..", is being deleted");
		removeAttackEntry(attackName);
	end
	
end

function removeAttackGroup(groupName)
	if (groupName == nil) then return; end
	
	CombatStats.AttackHistDB.CallFunctionForEachAttackNameRev(removeAttackGroupCallback, groupName);
end

function removeAttacksOlderThanCallback(attackName, olderDaysToDelete)
	local recAttack = CombatStats.AttackHistDB.GetAttackRec(attackName,false);
	
	if ((recAttack ~= nil) and (recAttack.lastCrit ~= nil)) then
		--debugPrint("recAttack.lastCrit: "..recAttack.lastCrit);
		if (olderDaysToDelete ~= 0)
		then
			--debugPrint("(time() - recAttack.lastCrit)/(24*60*60) = "..(time() - recAttack.lastCrit)/(24*60*60));
			if ((time() - recAttack.lastCrit)/(24*60*60) > olderDaysToDelete ) then
				removeAttackEntry(attackName);
			end
		else
			-- recAttack.lastCrit is known to be 0 at this point;
			--debugPrint("olderDaysToDelete: "..olderDaysToDelete);
			if (recAttack.lastCrit == 0) then
				removeAttackEntry(attackName);
			end
		end
	end
	
end

function removeAttacksOlderThan(olderDaysToDelete)
	if (olderDaysToDelete == nil) then return; end
	
	CombatStats.AttackHistDB.CallFunctionForEachAttackNameRev(removeAttacksOlderThanCallback, olderDaysToDelete);
end

--
-- Attack Main Drop down menu functionality
--

function CombatStatsAttackDropDown_Initialize(self)
	if (UIDROPDOWNMENU_MENU_VALUE) then
		--fillAttackNamesSubmenu(self,UIDROPDOWNMENU_MENU_VALUE);
		--local dropdown = self:GetParent();
		local dropdown = self;
		CombatStats.AttackHistDB.CallFunctionForEachAttackName(fillSubAttackMenuCallback, UIDROPDOWNMENU_MENU_VALUE, dropdown);
	else
		--fillAttackNamesMenu(self);
		--debugPrint("fillAttackNamesMenu");
		--local dropdown = self:GetParent();
		local dropdown = self;
		local iGrpNm;
		local value;
		
		if (_L.dirtyAttackMenu == 1) then
			--debugPrint("fillAttackNamesMenu--SORT");
			sortAttackNames(sortAttackMenuComp);
			_L.dirtyAttackMenu = 0;
		end
		
		resetGroupList();
		CombatStats.AttackHistDB.CallFunctionForEachAttackName(fillAttackNmCallback, dropdown);
		for iGrpNm, value in pairs(_L.groupList) do
			if (value == true) then
				CombatStats.Utils.AppendMenuItemSubmenu(iGrpNm, iGrpNm, nil, dropdown);
			end
		end
		CombatStats.Utils.FixLvlDropMenuButtons()
	end
	if (self.attackName) then
		CombatStatsAttackDropDown_SetText(self.attackName)
	end
end

function setDirtyAttackMenu()
	_L.dirtyAttackMenu = 1;
end

function fillAttackNmRegCallback(attackName)
	-- add dropdown		-- FIX
	local recAttack = CombatStats.AttackHistDB.GetAttackRec(attackName,false);
	if ((recAttack ~= nil) and (recAttack.group == nil)) then
		CombatStats.Utils.AppendMenuItem(attackName, attackName, CombatStatsAttack_OnClick, dropdown);
	end
	CombatStats.Utils.FixLvlDropMenuButtons()
end

function fillAttackNmGrpCallback(attackName)
	setActiveNameGroupList(CombatStats.AttackHistDB.GetGroupNameForAttackName(attackName,CombatStats_Config.CombatStats_AttackMenu1stGrping));
end

function fillAttackNmCallback(attackName,dropdown)
	local grpNm = CombatStats.AttackHistDB.GetGroupNameForAttackName(attackName,CombatStats_Config.CombatStats_AttackMenu1stGrping);
	if (grpNm == nil) then
		CombatStats.Utils.AppendMenuItem(attackName, attackName, CombatStatsAttack_OnClick, dropdown);
	else
		setActiveNameGroupList(CombatStats.AttackHistDB.GetGroupNameForAttackName(attackName,CombatStats_Config.CombatStats_AttackMenu1stGrping));
	end
	CombatStats.Utils.FixLvlDropMenuButtons()
end

function fillSubAttackMenuCallback(attackName,groupName,dropdown)
	local grpNm = CombatStats.AttackHistDB.GetGroupNameForAttackName(attackName,CombatStats_Config.CombatStats_AttackMenu1stGrping);
	if ((grpNm ~= nil) and (grpNm == groupName)) then
		CombatStats.Utils.AppendMenuItemSubmenuItem(
			attackName, 
			CombatStats.AttackHistDB.GetAttackNameIdx(attackName),
			CombatStatsAttackSubMenu_OnClick, dropdown	);
	end
	CombatStats.Utils.FixLvlDropMenuButtons()
end


function resetGroupList()
	local i;
	
	for i, _ in pairs(_L.groupList) do
		_L.groupList[i] = false;
	end
end

function clearGroupList(justInactive)
	local i;
	local value;
	justInactive = justInactive or false;
	
	if (justInactive) then
		for i, value in pairs(_L.groupList) do
			value = nil;
		end
	else
		_L.groupList = {}
	end
end

function setActiveNameGroupList(groupName)
	_L.groupList[groupName] = true;
end

function isActiveNameGroupList(groupName)
	if (groupName == nil) then return false; end
	
	return((_L.groupList[groupName] ~= nil) and (_L.groupList[groupName] == true));
end

--[[
function fillAttackNamesMenu(self)
	--debugPrint("fillAttackNamesMenu");
	local dropdown = self:GetParent();
	local iGrpNm;
	local value;
	
	if (_L.dirtyAttackMenu == 1) then
		--debugPrint("fillAttackNamesMenu--SORT");
		sortAttackNames(sortAttackMenuComp);
		_L.dirtyAttackMenu = 0;
	end
	
	resetGroupList();
	CombatStats.AttackHistDB.CallFunctionForEachAttackName(fillAttackNmCallback, dropdown);
	for iGrpNm, value in pairs(_L.groupList) do
		if (value == true) then
			CombatStats.Utils.AppendMenuItemSubmenu(iGrpNm, iGrpNm, nil, dropdown);
		end
		- - [ [
		if (value == true) then
			debugPrint("iGrpNm/value "..iGrpNm.."/true");
		else
			debugPrint("iGrpNm/value "..iGrpNm.."/false");
		end
		] ]
	end
	CombatStats.Utils.FixLvlDropMenuButtons()
end
]]

--[[
function fillAttackNamesSubmenu(self,groupName)
	local dropdown = self:GetParent();
	CombatStats.AttackHistDB.CallFunctionForEachAttackName(fillSubAttackMenuCallback, groupName, dropdown);
end
]]

--
-- Edit Drop down menu functionality
--

function CombatStatsEditDropDown_OnLoad(self)
	UIDropDownMenu_Initialize(self, editDropDownMenuInitialize);
	UIDropDownMenu_SetWidth(self, 10)		-- in XML file now;
	--UIDropDownMenu_SetSelectedID(self,1)
end

function editDropDownMenuInitialize(self,...)
	local info;
	local aStr;
	local dropdown = self:GetParent();
	local currentAttack = nil;
	local attackGroup = nil;
	
	if (CombatStats_Config == nil) then return end
	
	--[[
	for i=1, select("#", ...), 1 do
		--msgPrint("["..i.."] = "..(select(i, ...) or "nil") )
		msgPrint("["..i.."] = ")
	end
	msgPrint("UIDROPDOWNMENU_MENU_VALUE: "..(UIDROPDOWNMENU_MENU_VALUE or "nil"))
	]]
	
	if (CombatStats_Config.CombatStats_AttackMenuSort == 0)
		then CombatStats.Utils.AppendMenuChkItem(CS_ED_DROPDN_AZSORT_TEXT,0,CombatStatsEditDropDown_ChangeAttackSort,dropdown);
		else CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_AZSORT_TEXT,0,CombatStatsEditDropDown_ChangeAttackSort,dropdown);
	end
	if (CombatStats_Config.CombatStats_AttackMenuSort == 1)
		then CombatStats.Utils.AppendMenuChkItem(CS_ED_DROPDN_TIMESORT_TEXT,1,CombatStatsEditDropDown_ChangeAttackSort,dropdown);
		else CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_TIMESORT_TEXT,1,CombatStatsEditDropDown_ChangeAttackSort,dropdown);
	end
	if (CombatStats_Config.CombatStats_AttackMenuSort == 2)
		then CombatStats.Utils.AppendMenuChkItem(CS_ED_DROPDN_MXCRITSORT_TEXT,2,CombatStatsEditDropDown_ChangeAttackSort,dropdown);
		else CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_MXCRITSORT_TEXT,2,CombatStatsEditDropDown_ChangeAttackSort,dropdown);
	end
	if (CombatStats_Config.CombatStats_AttackMenuSort == 3)
		then CombatStats.Utils.AppendMenuChkItem(CS_ED_DROPDN_MXNONCRITSORT_TEXT,3,CombatStatsEditDropDown_ChangeAttackSort,dropdown);
		else CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_MXNONCRITSORT_TEXT,3,CombatStatsEditDropDown_ChangeAttackSort,dropdown);
	end
	CombatStats.Utils.AppendMenuItemSeparator("- - - - -",dropdown);
	CombatStats.Utils.AppendMenuItem(groupsMenuToggleLabel(),1,CombatStatsEditDropDown_ToggleBeginGroups,dropdown);
	CombatStats.Utils.AppendMenuItem(autoResetBattleMenuToggleLabel(),1,CombatStatsEditDropDown_ToggleAutoResetBattle,dropdown);
	currentAttack = gCS.currentAttack;
	
	if(currentAttack ~= nil and currentAttack ~= CS_TEXT_NA and currentAttack ~= CS_ATTACK_TOTAL_LABEL
					and currentAttack ~= CS_ATTACK_TOTAL_LABEL) then
		CombatStats.Utils.AppendMenuItemSeparator("- - - - -",dropdown);
		if(string.len(currentAttack) < 16)
			then aStr = string.format(CS_ED_DROPDN_DEL__DAYSATTACK_TEXT, currentAttack);
			else aStr = string.format(CS_ED_DROPDN_DEL__DAYSATTACK_TEXT, string.sub(currentAttack,1,15).."...");
		end
		CombatStats.Utils.AppendMenuItem(aStr,currentAttack,CombatStatsEditDropDown_DeleteAnAttack,dropdown);
		attackGroup = CombatStats.AttackHistDB.GetGroupNameForAttackName(currentAttack);
		if(attackGroup ~= nil) then
			if(string.len(attackGroup) < 16)
				then aStr = string.format(CS_ED_DROPDN_DEL__DAYSATTACKGRP_TEXT, attackGroup);
				else aStr = string.format(CS_ED_DROPDN_DEL__DAYSATTACKGRP_TEXT, string.sub(attackGroup,1,15).."...");
			end
			CombatStats.Utils.AppendMenuItem(aStr,attackGroup,CombatStatsEditDropDown_DeleteAttackGroup,dropdown);
		end
	end
	
	CombatStats.Utils.AppendMenuItemSeparator("- - - - -",dropdown);
	CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_DEL_1_DAYS_TEXT,1,CombatStatsEditDropDown_DeleteAttacksOlderThan,dropdown);
	CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_DEL_5_DAYS_TEXT,5,CombatStatsEditDropDown_DeleteAttacksOlderThan,dropdown);
	CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_DEL_7_DAYS_TEXT,7,CombatStatsEditDropDown_DeleteAttacksOlderThan,dropdown);
	CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_DEL_30_DAYS_TEXT,30,CombatStatsEditDropDown_DeleteAttacksOlderThan,dropdown);
	CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_DEL_90_DAYS_TEXT,90,CombatStatsEditDropDown_DeleteAttacksOlderThan,dropdown);
	CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_DEL_180_DAYS_TEXT,180,CombatStatsEditDropDown_DeleteAttacksOlderThan,dropdown);
	CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_DEL_365_DAYS_TEXT,365,CombatStatsEditDropDown_DeleteAttacksOlderThan,dropdown);
	CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_DEL_730_DAYS_TEXT,730,CombatStatsEditDropDown_DeleteAttacksOlderThan,dropdown);
	CombatStats.Utils.AppendMenuItem(CS_ED_DROPDN_DEL_0_DAYS_TEXT,0,CombatStatsEditDropDown_DeleteAttacksOlderThan,dropdown);
	
	CombatStats.Utils.FixLvlDropMenuButtons()
end

function groupsMenuToggleLabel()
	if(CombatStats_Config.CombatStats_AttackMenu1stGrping == 1)
		then return CS_ED_DROPDN_DISABLE_GROUPING_TEXT;
		else return CS_ED_DROPDN_ENABLE_GROUPING_TEXT;
	end
end

function autoResetBattleMenuToggleLabel()
	if(CombatStats_Config.CombatStats_AutoBattleReset)
		then return CS_ED_DROPDN_DISABLE_AUTO_NEW_BAT_RESET_TEXT;
		else return CS_ED_DROPDN_ENABLE_AUTO_NEW_BAT_RESET_TEXT;
	end
end

function CombatStatsEditDropDown_ToggleBeginGroups(self)
	--debugPrint("CombatStats_Config.CombatStats_AttackMenu1stGrping "..TEXT(CombatStats_Config.CombatStats_AttackMenu1stGrping));
	if(CombatStats_Config.CombatStats_AttackMenu1stGrping == 0)
		then CombatStats_Config.CombatStats_AttackMenu1stGrping = 1;
		else CombatStats_Config.CombatStats_AttackMenu1stGrping = 0;
	end
	setGrpSortType(CombatStats_Config.CombatStats_AttackMenu1stGrping);
	
	setDirtyAttackMenu();
end

function CombatStatsEditDropDown_ToggleAutoResetBattle(self)
	--debugPrint("CombatStats_Config.CombatStats_AutoBattleReset "..TEXT(CombatStats_Config.CombatStats_AutoBattleReset));
	--if(CombatStats_Config.CombatStats_AutoBattleReset == 0)
	--	then CombatStats_Config.CombatStats_AutoBattleReset = 1;
	--	else CombatStats_Config.CombatStats_AutoBattleReset = 0;
	--end
	CombatStats_SetAutoBatReset()
end

function CombatStatsEditDropDown_ChangeAttackSort(self)
	--debugPrint("attackMenuSort before: "..CombatStats_Config.CombatStats_AttackMenuSort..", after: "..self.value);
	CombatStats_Config.CombatStats_AttackMenuSort = self.value;
	setDirtyAttackMenu();
end

function CombatStatsEditDropDown_DeleteAnAttack(self)
	removeAttackEntry(self.value);
end

function CombatStatsEditDropDown_DeleteAttackGroup(self)
	removeAttackGroup(self.value);
end

function CombatStatsEditDropDown_DeleteAttacksOlderThan(self)
	removeAttacksOlderThan(self.value);
end

--=============================================================================
-- Initialization
--=============================================================================
if (CombatStats and CombatStats.DetailFrame) then return; end;
debugPrint("CS_DetailFrame.lua loaded");

-------------------------------------------------------------------------------
-- Public API
-------------------------------------------------------------------------------
if (not CombatStats) then CombatStats = {}; end

CombatStats.DetailFrame = {
	Load = load;
	
	SetDirtyAttackMenu = setDirtyAttackMenu;
}

--[[
CombatStatsAttack_OnClick
CombatStatsAttackSubMenu_OnClick
CombatStatsAttackDropDown_GetText
CombatStatsAttackDropDown_SetText
CombatStatsAttackDropDown_OnLoad
CombatStatsText_ResetFrameGUI
CombatStatsText_ShowFrame
CombatStats_UpdateDetails
CombatStats_AddToGrpList
CombatStatsAttackDropDown_Initialize
CombatStatsEditDropDown_OnLoad
CombatStatsEditDropDown_ToggleBeginGroups
CombatStatsEditDropDown_ChangeAttackSort
CombatStatsEditDropDown_DeleteAnAttack
CombatStatsEditDropDown_DeleteAttackGroup
CombatStatsEditDropDown_DeleteAttacksOlderThan
]]
